#importing some useful packages
import cv2
import matplotlib.pyplot as plt
import numpy as np
from skimage import io


def augment_brightness_camera_images(image):
    image1 = cv2.cvtColor(image,cv2.COLOR_RGB2HSV)
    random_bright = 0.25+np.random.uniform()
    #print(random_bright)
    image1[:,:,2] = image1[:,:,2]*random_bright
    image1 = cv2.cvtColor(image1,cv2.COLOR_HSV2RGB)
    return image1
#img_oct = cv2.imread(image_path)
def transform_image(img,ang_range,shear_range,trans_range):
    '''
    This function transforms images to generate new images.
    The function takes in following arguments,
    1- Image
    2- ang_range: Range of angles for rotation
    3- shear_range: Range of values to apply affine transform to
    4- trans_range: Range of values to apply translations over. 
    
    A Random uniform distribution is used to generate different parameters for transformation
    
    '''
    # Rotation

    ang_rot = np.random.uniform(ang_range)-ang_range/2
    rows,cols,ch = img.shape    
    Rot_M = cv2.getRotationMatrix2D((cols/2,rows/2),ang_rot,1)

    # Translation
    tr_x = trans_range*np.random.uniform()-trans_range/2
    tr_y = trans_range*np.random.uniform()-trans_range/2
    Trans_M = np.float32([[1,0,tr_x],[0,1,tr_y]])

    # Shear
    pts1 = np.float32([[5,5],[20,5],[5,20]])

    pt1 = 5+shear_range*np.random.uniform()-shear_range/2
    pt2 = 20+shear_range*np.random.uniform()-shear_range/2
    
    # Brightness 
    

    pts2 = np.float32([[pt1,5],[pt2,pt1],[5,pt2]])

    shear_M = cv2.getAffineTransform(pts1,pts2)
        
    img = cv2.warpAffine(img,Rot_M,(cols,rows))
    img = cv2.warpAffine(img,Trans_M,(cols,rows))
    img = cv2.warpAffine(img,shear_M,(cols,rows))
    
    #img = augment_brightness_camera_images(img)
    #image_path = '/home/shohanursobuj/MEGAsync/DRUSEN-9861332-1.jpeg'
    #img_oct = cv2.imread(image_path)
    return img


def save_array(image_path,ang_range,shear_range,trans_range,input_size):
    data = []
    for i in range(input_size):
        img = transform_image(image_path,ang_range,shear_range,trans_range)
        data.append(img)
    return data

def save_img(image_path,ang_range,shear_range,trans_range,input_size):
    data = []
    for i in range(input_size):
        img = transform_image(image_path,ang_range,shear_range,trans_range)
        data.append(img)
        io.imsave('img_'+str(i)+'.jpg',img) # save the images
    return data
    #return img
#


